@@ -8,20 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_codebuild._jsii
-import aws_cdk.aws_codecommit._jsii
-import aws_cdk.aws_events._jsii
-import aws_cdk.aws_events_targets._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-dependency-check",
-    "1.48.0",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-dependency-check@1.48.0.jsii.tgz",
+    "cdk-dependency-check@2.0.0.jsii.tgz",
 )
 
 __all__ = [
